@@ -277,6 +277,8 @@ int vutil_readconf (const char *name, VSERVER_CONF &conf)
 			}
 		}
 		ret = pclose (fin);
+		// fprintf (stderr,"ret = %d\n",ret);
+		if (ret != 0) ret = -1;
 	}
 	return ret;
 }
